==> paper-api-1.21.4-R0.1-20250609.101859-227-sources.jar: org/bukkit/event/weather/ThunderChangeEvent.java <==
package org.bukkit.event.weather;

import org.bukkit.World;
import org.bukkit.event.Cancellable;
import org.bukkit.event.HandlerList;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.NotNull;

/**
 * Stores data for thunder state changing in a world
 */
public class ThunderChangeEvent extends WeatherEvent implements Cancellable {
    private static final HandlerList handlers = new HandlerList();
    private boolean canceled;
    private final boolean to;
    private final Cause cause;

    @ApiStatus.Internal
    public ThunderChangeEvent(@NotNull final World world, final boolean to, @NotNull final Cause cause) {
        super(world);
        this.to = to;
        this.cause = cause;
    }

    @Deprecated(forRemoval = true)
    public ThunderChangeEvent(@NotNull final World world, final boolean to) {
        super(world);
        this.to = to;
        this.cause = Cause.UNKNOWN; // Paper
    }

    @Override
    public boolean isCancelled() {
        return canceled;
    }

    @Override
    public void setCancelled(boolean cancel) {
        canceled = cancel;
    }

    /**
     * Gets the state of thunder that the world is being set to
     *
     * @return true if the weather is being set to thundering, false otherwise
     */
    public boolean toThunderState() {
        return to;
    }

    @NotNull
    @Override
    public HandlerList getHandlers() {
        return handlers;
    }

    @NotNull
    public static HandlerList getHandlerList() {
        return handlers;
    }
    // Paper start
    /**
     * Gets the cause of the weather change.
     *
     * @return the weather change cause
     */
    @NotNull
    public Cause getCause() {
        return this.cause;
    }

    public enum Cause {
        COMMAND,
        NATURAL,
        SLEEP,
        PLUGIN,
        UNKNOWN
    }
    // Paper end
}

==> paper-api-1.21.5-R0.1-20250521.163020-4-sources.jar: org/bukkit/event/weather/ThunderChangeEvent.java <==
package org.bukkit.event.weather;

import org.bukkit.World;
import org.bukkit.event.Cancellable;
import org.bukkit.event.HandlerList;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.NotNull;

/**
 * Stores data for thunder state changing in a world
 */
public class ThunderChangeEvent extends WeatherEvent implements Cancellable {

    private static final HandlerList HANDLER_LIST = new HandlerList();

    private final boolean newThunderState;
    private final Cause cause;

    private boolean cancelled;

    @ApiStatus.Internal
    public ThunderChangeEvent(@NotNull final World world, final boolean newThunderState, @NotNull final Cause cause) {
        super(world);
        this.newThunderState = newThunderState;
        this.cause = cause;
    }

    @ApiStatus.Internal
    @Deprecated(forRemoval = true)
    public ThunderChangeEvent(@NotNull final World world, final boolean newThunderState) {
        this(world, newThunderState, Cause.UNKNOWN);
    }

    /**
     * Gets the state of thunder that the world is being set to
     *
     * @return {@code true} if the weather is being set to thundering, {@code false} otherwise
     */
    public boolean toThunderState() {
        return this.newThunderState;
    }

    /**
     * Gets the cause of the weather change.
     *
     * @return the weather change cause
     */
    @NotNull
    public Cause getCause() {
        return this.cause;
    }

    @Override
    public boolean isCancelled() {
        return this.cancelled;
    }

    @Override
    public void setCancelled(boolean cancel) {
        this.cancelled = cancel;
    }

    @NotNull
    @Override
    public HandlerList getHandlers() {
        return HANDLER_LIST;
    }

    @NotNull
    public static HandlerList getHandlerList() {
        return HANDLER_LIST;
    }

    public enum Cause {
        COMMAND,
        NATURAL,
        SLEEP,
        PLUGIN,
        UNKNOWN
    }
}
